pub struct ScanTask {
pub handle: Arc<JoinHandle<Result<(), Report>>>,
pub cmd_sender: Sender<ScanTaskCommand>,
}Expand description
Scan task handle and command channel sender
Fields
handle: Arc<JoinHandle<Result<(), Report>>>JoinHandle of scan task
cmd_sender: Sender<ScanTaskCommand>Task command channel sender
Implementations
Sourceimpl ScanTask
impl ScanTask
Sourcepub fn process_messages(
cmd_receiver: &mut Receiver<ScanTaskCommand>,
registered_keys: &mut HashMap<SaplingScanningKey, DiversifiableFullViewingKey>,
network: &Network,
) -> Result<(HashMap<SaplingScanningKey, (DiversifiableFullViewingKey, Height)>, HashMap<SaplingScanningKey, Sender<ScanResult>>, Vec<(Receiver<ScanResult>, Sender<Receiver<ScanResult>>)>), Report>
pub fn process_messages( cmd_receiver: &mut Receiver<ScanTaskCommand>, registered_keys: &mut HashMap<SaplingScanningKey, DiversifiableFullViewingKey>, network: &Network, ) -> Result<(HashMap<SaplingScanningKey, (DiversifiableFullViewingKey, Height)>, HashMap<SaplingScanningKey, Sender<ScanResult>>, Vec<(Receiver<ScanResult>, Sender<Receiver<ScanResult>>)>), Report>
Accepts the scan task’s parsed_key collection and a reference to the command channel receiver
Processes messages in the scan task channel, updating parsed_keys if required.
Returns newly registered keys for scanning.
Sourcepub fn send(
&mut self,
command: ScanTaskCommand,
) -> Result<(), TrySendError<ScanTaskCommand>>
pub fn send( &mut self, command: ScanTaskCommand, ) -> Result<(), TrySendError<ScanTaskCommand>>
Sends a command to the scan task
Sourcepub fn remove_keys(
&mut self,
keys: Vec<String>,
) -> Result<Receiver<()>, TrySendError<ScanTaskCommand>>
pub fn remove_keys( &mut self, keys: Vec<String>, ) -> Result<Receiver<()>, TrySendError<ScanTaskCommand>>
Sends a message to the scan task to remove the provided viewing keys.
Returns a oneshot channel receiver to notify the caller when the keys have been removed.
Sourcepub fn register_keys(
&mut self,
keys: Vec<(String, Option<u32>)>,
) -> Result<Receiver<Vec<String>>, TrySendError<ScanTaskCommand>>
pub fn register_keys( &mut self, keys: Vec<(String, Option<u32>)>, ) -> Result<Receiver<Vec<String>>, TrySendError<ScanTaskCommand>>
Sends a message to the scan task to start scanning for the provided viewing keys.
Sourcepub fn subscribe(
&mut self,
keys: HashSet<SaplingScanningKey>,
) -> Result<Receiver<Receiver<ScanResult>>, TrySendError<ScanTaskCommand>>
pub fn subscribe( &mut self, keys: HashSet<SaplingScanningKey>, ) -> Result<Receiver<Receiver<ScanResult>>, TrySendError<ScanTaskCommand>>
Sends a message to the scan task to start sending the results for the provided viewing keys to a channel.
Returns the channel receiver.